@@ -136,7 +136,7 @@ class ShortcutParameter(ActionParameter):
     if cls.REGISTRY:
       with warnings.catch_warnings():
         warnings.simplefilter('ignore', UserWarning)
-        for param in params_flattened(cls.REGISTRY):
+        for param in params_flattened(cls.REGISTRY.params):
           cls.REGISTRY.deleteShortcut(PrjParam(param.name(), param.defaultValue()))
     if createIfNone and shortcutsRegistry is None:
       shortcutsRegistry = ShortcutsEditor(**createOpts)
