@@ -88,12 +88,13 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
     else:
       parentMenu = self.menu
 
-    shcValue = None
+    shcValue = opts = None
     if 'btnOpts' in kwargs:
       opts = PrjParam(**kwargs['btnOpts'])
       opts.opts.setdefault('ownerObj', self)
       kwargs.setdefault('name', opts.name)
       kwargs['btnOpts'] = opts
+      shcValue = opts.value
     proc = editor.registerFunc(func, **kwargs)
     act = parentMenu.addAction(proc.name)
     if ShortcutParameter.REGISTRY and shcValue and self._makeMenuShortcuts:
@@ -108,13 +109,19 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
     #   have an import inside a function
     if groupName is None and btnOpts is None:
       raise ValueError('Must provide either group name or button options')
+    elif btnOpts is None:
+      btnOpts = PrjParam(groupName)
     if groupName is None:
       groupName = btnOpts.name
-    self.menu.addAction(groupName, lambda: paramWindow(self.toolsEditor.params.child(groupName)))
+    act = self.menu.addAction(groupName, lambda: paramWindow(self.toolsEditor.params.child(groupName)))
     if nameList is None:
       nameList = [None]*len(funcList)
     for title, func in zip(nameList, funcList):
       self.toolsEditor.registerFunc(func, name=title, namePath=(groupName,))
+    if ShortcutParameter.REGISTRY and btnOpts.value and self._makeMenuShortcuts:
+      ShortcutParameter.REGISTRY.registerAction(btnOpts, act,
+                                                namePath=(self.__groupingName__,))
+
     self.menu.addSeparator()
 
 
