@@ -116,7 +116,7 @@ class ShortcutsEditor(ParamEditor):
       tip = param.opts.get('tip', '')
       tip = helpTextToRichText(tip, newTooltipText)
       newBtn.setToolTip(tip)
-    newBtn.setShortcut(param.seqEdit.keySequence())
+      newBtn.setShortcut(newSeq)
     param.sigValueChanged.connect(shcChanged)
     shcChanged(None, btnOpts.value)
     if returnParam:
