@@ -1,7 +1,8 @@
 from __future__ import annotations
 
 from textwrap import wrap
-from typing import Union, Sequence, Literal, Any
+from typing import Union, Sequence, Any
+from typing_extensions import Literal
 
 import numpy as np
 import pandas as pd
